{% load i18n %}
<div class="card card-body rounded mt-2">
    <div id="chart">
        <div class="d-flex justify-content-center align-items-center w-100">
            <div class="spinner-border text-primary" role="status">
                <span class="visually-hidden">{% translate "Loading..." %}</span>
            </div>
        </div>
    </div>
</div>
