{% load i18n %}
{% load navactive %}

<!-- Only show the following links if the user is authenticated -->
{% if request.user.is_authenticated %}
    <li class="nav-item">
        <a class="nav-link" href="{% url 'beltradar:view_my_sessions' %}">{% translate 'My Sessions' %}</a>
    </li>
{% endif %}
