@media all {
    .beltradar-class {
        color: rgb(51 51 51);
        font-size: 16px;
    }

    /* Highlight Class */
    .highlight {
        animation: highlight-animation 2s ease; /* Animation für das Highlight */
    }

    @keyframes highlight-animation {
        0% { box-shadow: inset 0 0 0 9999px rgb(0 255 150 / 50%); }
        100% { box-shadow: inset 0 0 0 9999px rgb(0 255 150 / 0%); }
    }
}
