{% extends 'beltradar/base.html' %}
{% load i18n %}

{% block page_template_title %}
    {{ title }}
{% endblock page_template_title %}

{% block page_topic %}
    <h1 class="page-header text-center">
        {{ title }}
    </h1>
{% endblock page_topic %}

{% block aabeltradar_header %}
    <div class="card">
        <div class="card-header bg-primary rounded d-flex align-items-center">
            <h3>{% translate "Add Survey Snapshot" %}</h3>
            <div class="px-2">
                <a href="{% url 'beltradar:view_session' public_id=session.public_id %}">
                    <span class="btn btn-secondary">{% translate 'Back to Session' %}</span>
                </a>
            </div>
        </div>
    </div>
{% endblock aabeltradar_header %}

{% block aabeltradar_block %}
    <div class="card card-body mt-2 rounded">
        <div class="card-footer">
            <p class="text-muted">
                {% translate "Note: You can only add a new snapshot every 5 minutes to prevent abuse. Please ensure your data is correct before submitting." %}
            </p>
            {% include 'beltradar/partials/forms/batch_ore.html' %}
        </div>
    </div>
{% endblock aabeltradar_block %}


{% block extra_css %}
    {% include 'bundles/datatables-2-css-bs5.html' %}
    {% include 'bundles/datatables-2-columncontrol-css-bs5.html' %}
    {% include 'beltradar/bundles/aa-beltradar-css.html' %}
{% endblock %}

{% block extra_javascript %}
    <script>
        /**
         * Override settings for Belt Radar
         */
        const aaBeltRadarSettingsOverride = {
        };
    </script>
    {% include 'beltradar/bundles/aa-beltradar-js.html' %}
    {% include 'bundles/datatables-2-js-bs5.html' %}
    {% include 'bundles/datatables-2-columncontrol-js-bs5.html' %}
{% endblock extra_javascript %}
